@@ -375,7 +375,7 @@ def selection(title, values, alwaysask=False):
     dialog.set_icon(TRYTON_ICON)
     dialog.set_has_separator(True)
     dialog.set_default_response(gtk.RESPONSE_OK)
-    dialog.set_size_request(400, 400)
+    dialog.set_default_size(400, 400)
 
     label = gtk.Label(title or _('Your selection:'))
     dialog.vbox.pack_start(label, False, False)
@@ -888,7 +888,7 @@ class ErrorDialog(UniqueDialog):
         vbox.pack_start(button_roundup, False, False)
 
         dialog.vbox.pack_start(vbox)
-        dialog.set_size_request(600, 400)
+        dialog.set_default_size(600, 400)
         return dialog
 
     def __call__(self, title, details):
@@ -1034,7 +1034,7 @@ def process_exception(exception, *args, **kwargs):
                 'until its fingerprint is fixed.'), _('Security risk!'))
             from tryton.gui.main import Main
             Main.sig_quit()
-        elif exception.faultCode == 'NotLogged':
+        elif exception.faultCode.startswith('403'):
             if rpc.CONNECTION is None:
                 message(_('Connection error!\n'
                         'Unable to connect to the server!'))
@@ -1079,16 +1079,8 @@ def process_exception(exception, *args, **kwargs):
             else:
                 message(_('Concurrency Exception'), msg_type=gtk.MESSAGE_ERROR)
                 return False
-        elif exception.faultCode == 'NotLogged':
+        elif exception.faultCode.startswith('403'):
             from tryton.gui.main import Main
-            if kwargs.get('session', rpc._SESSION) != rpc._SESSION:
-                if args:
-                    try:
-                        return rpc_execute(*args)
-                    except TrytonServerError, exception:
-                        return process_exception(exception, *args,
-                            rpc_execute=rpc_execute)
-                return
             if not PLOCK.acquire(False):
                 return False
             hostname = rpc._HOST
@@ -1258,7 +1250,6 @@ class RPCProgress(object):
     def run(self, process_exception_p=True, callback=None):
         self.process_exception_p = process_exception_p
         self.callback = callback
-        self.session = rpc._SESSION
         if self.parent.window:
             watch = gtk.gdk.Cursor(gtk.gdk.WATCH)
             self.parent.window.set_cursor(watch)
@@ -1279,7 +1270,7 @@ class RPCProgress(object):
                     return RPCProgress('execute',
                         args).run(self.process_exception_p)
                 result = process_exception(self.exception, *self.args,
-                    rpc_execute=rpc_execute, session=self.session)
+                    rpc_execute=rpc_execute)
                 if result is False:
                     self.exception = RPCException(self.exception)
                 else:
@@ -1386,11 +1377,12 @@ def humanize(size):
 
 def get_hostname(netloc):
     if '[' in netloc and ']' in netloc:
-        return netloc.split(']')[0][1:]
+        hostname = netloc.split(']')[0][1:]
     elif ':' in netloc:
-        return netloc.split(':')[0]
+        hostname = netloc.split(':')[0]
     else:
-        return netloc
+        hostname = netloc
+    return hostname.strip()
 
 
 def get_port(netloc):
