@@ -47,7 +47,7 @@ You can save any graphs in PNG file with right-click on it.
         self.win.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
         self.win.set_icon(TRYTON_ICON)
         self.win.set_has_separator(True)
-        self.win.set_size_request(500, 400)
+        self.win.set_default_size(500, 400)
 
         self.win.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
         self.win.set_default_response(gtk.RESPONSE_CLOSE)
