@@ -44,7 +44,8 @@ class Group(SignalEvent, list):
     def readonly(self):
         # Must skip res.user for Preference windows
         if (self._context.get('_datetime')
-                or (not MODELACCESS[self.model_name]['write']
+                or (not (MODELACCESS[self.model_name]['write']
+                        or MODELACCESS[self.model_name]['create'])
                     and not self.skip_model_access)):
             return True
         return self.__readonly
@@ -380,7 +381,7 @@ class Group(SignalEvent, list):
             return None
         return self[self.current_idx]
 
-    def add_fields(self, fields, signal=True):
+    def add_fields(self, fields):
         to_add = {}
         for name, attr in fields.iteritems():
             if name not in self.fields:
@@ -404,7 +405,9 @@ class Group(SignalEvent, list):
             except RPCException:
                 return False
             for record in new:
-                record.set_default(values, signal=signal)
+                record.set_default(values, signal=False)
+            # Trigger signal only once with the last record
+            record.signal('record-changed')
 
     def get(self, id):
         'Return record with the id'
