@@ -96,7 +96,6 @@ class Reference(Many2One, SelectionMixin, PopdownMixin):
         if not self.changed:
             return
         self.wid_text.set_text('')
-        self.wid_text.set_position(0)
         model = self.get_model()
         if model:
             value = (model, (-1, ''))
@@ -120,7 +119,7 @@ class Reference(Many2One, SelectionMixin, PopdownMixin):
             if (model != self.get_model()
                     or name != self.wid_text.get_text()):
                 field.set_client(record, None)
-                self.wid_text.set_text('')
+                self.set_text('')
 
     def set_text(self, value):
         if value:
