@@ -25,6 +25,8 @@ class Selection(Widget, SelectionMixin, PopdownMixin):
         child.connect('activate', lambda *a: self._focus_out())
         child.connect('focus-out-event', lambda *a: self._focus_out())
         self.entry.connect('changed', self.changed)
+        self.entry.connect('move-active', self._move_active)
+        self.entry.connect('scroll-event', self._scroll_event)
         self.widget.pack_start(self.entry)
         self.widget.set_focus_chain([child])
 
@@ -40,6 +42,14 @@ class Selection(Widget, SelectionMixin, PopdownMixin):
         # Must be deferred because it triggers a display of the form
         gobject.idle_add(focus_out)
 
+    def _move_active(self, combobox, scroll_type):
+        if not combobox.child.get_editable():
+            combobox.emit_stop_by_name('move-active')
+
+    def _scroll_event(self, combobox, event):
+        if not combobox.child.get_editable():
+            combobox.emit_stop_by_name('scroll-event')
+
     def _readonly_set(self, value):
         super(Selection, self)._readonly_set(value)
         self.entry.child.set_editable(not value)
