@@ -480,6 +480,7 @@ class ScreenContainer(object):
             self.search_window.set_icon(TRYTON_ICON)
             self.search_window.set_decorated(False)
             self.search_window.set_deletable(False)
+            self.search_window.connect('delete-event', lambda *a: True)
             self.search_window.connect('key-press-event', key_press)
             vbox = gtk.VBox()
             fields = [f for f in self.screen.domain_parser.fields.itervalues()
@@ -570,7 +571,9 @@ class ScreenContainer(object):
 
         # Move the window under the button
         x, y = button.window.get_origin()
-        self.search_window.move(x, y + button_allocation.height)
+        self.search_window.move(
+            x + button_allocation.x,
+            y + button_allocation.y + button_allocation.height)
 
         from tryton.gui.main import Main
         page = Main.get_main().get_page()
